:::{include} ../README.md
:::

```{toctree}
:hidden:
:caption: Guides

dev_guide
config_current
update_defaults
slurm_submit_guide
```

```{toctree}
:hidden:
:caption: Design & Internals

code_structure
parallelization
why_adios2
memory_estimation
memory_management
image_concatenation
per_channel_convergence
briggsbwtaper
adios2_convert
check_adios2
benchmark_zfs_pools
```

```{toctree}
:hidden:
:caption: API Reference

api/pclean
api/config
api/params
api/imaging
api/parallel
api/utils
```

```{toctree}
:hidden:
:caption: Performance Reports

reports/alma_pclean_vs_tclean_v1
reports/tclean_pclean_perf_v2
```
